Learn R Programming

OPDOE (version 1.0-10)

design.reg.polynom: Design for Polynomial Regression

Description

Determines locations and number of replications for a polynomial regression design.

Needs specification of order of polynom, borders of intervall and total number of measurements as input.

Usage

design.regression.polynom(a, b, k, n)
design.reg.polynom(...)

Arguments

a

lower bound of interval

b

upper bound of interval

k

order of polynom

n

total number of planned measurements

...

only used for call wrapper design.reg.polynom

Value

Object of class design.regression

Details

Uses Legendre Polynomials to determine the support points for the design:

If \(a=-1\), \(b=1\): places \(k +1\) support points in \([-1,1]\), located at the roots of \((1-x^{2})\frac{dP_{k}(x)}{dx}\) where \(P_{k}(x)\) is the Legendre polynomial of degree \(k\)).

Distributes the n measurements almost equally over the support points.

References

Dieter Rasch, Juergen Pilz, L.R. Verdooren, Albrecht Gebhardt: Optimal Experimental Design with R, Chapman and Hall/CRC, 2011

Examples

Run this code
# NOT RUN {
x <- design.reg.polynom(10, 100, 3, 45)
x
# }

Run the code above in your browser using DataLab